import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { useDataMap } from './useDataMap';
import { useDataEarthquake } from './useDataEarthquake';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';
import { csv, scaleSqrt, scaleOrdinal, max, format, extent, scaleLinear} from 'd3';

const width = 960;
const height = 500;
const margin = { top: 20, right: 200, bottom: 20, left: 90 };
const xAxisLabelOffset = 45;
const yAxisLabelOffset = 20;
const circleRadius = 6;
const fadeOpacity = 0.2;
const legendOffset = 210;

const App = () => {
  const mapData = useDataMap();
  const earthquakeData = useDataEarthquake();
  const [hoveredValue, setHoveredValue] = useState(null);
  
  if (!mapData) {
    return <pre>Loading...</pre>;
  }
  
  if (!earthquakeData) {
    return <pre>Loading...</pre>;
  }
  
  const sizeValue = d => d.FocalDepth;
  const maxRadius = 5;

  const sizeScale = scaleSqrt()
    .domain([0, max(earthquakeData, sizeValue)])
    .range([0, maxRadius]);
  
  console.log(sizeValue)
  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
  const xValue = d => d.Longitude;
  const yValue = d => d.Latitude;
  
  const colorValue = d => d.Tsu;
	const colorLegendLabel = 'Tsu';
  const colorScale = scaleOrdinal()
    .domain(earthquakeData.map(colorValue))
    .range(['#A28B6C','#48bcbc']);
  
  const filteredData = earthquakeData.filter(d => {
     if (hoveredValue) return hoveredValue === colorValue(d);
    else return !!d;
  });
  const xScale = scaleLinear()
    .domain(extent(earthquakeData, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(earthquakeData, yValue))
    .range([0, innerHeight])
    .nice();
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${innerWidth + legendOffset}, 40)`}>
          <text x={xAxisLabelOffset} y={-yAxisLabelOffset} className="axis-label" textAnchor="middle">
          {colorLegendLabel}
          </text>
          <ColorLegend
            tickSpacing={22}
            tickSize={10}
            tickTextOffset={14}
            tickSize={circleRadius}
            colorScale={colorScale}
            onHover={setHoveredValue}
            hoveredValue={hoveredValue}
          />
        </g>
      
      <g transform={`translate(0, 0)`}>
      	<Marks 
        mapData={mapData} 
        earthquakeData = {filteredData}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
        colorScale={colorScale}
  			colorValue={colorValue}
          />
      </g>
       
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);